1.0.0 API documentation: bitfield.hpp File Reference

| 1.0.0 API documentation

Functions
bitfield.hpp File Reference

GLM_GTC_bitfield More...

Go to the source code of this file.

## Functions
GLM_FUNC_DECL glm::u8vec2 | bitfieldDeinterleave (glm::uint16 x)
| Deinterleaves the bits of x. More...
GLM_FUNC_DECL glm::u16vec2 | bitfieldDeinterleave (glm::uint32 x)
| Deinterleaves the bits of x. More...
GLM_FUNC_DECL glm::u32vec2 | bitfieldDeinterleave (glm::uint64 x)
| Deinterleaves the bits of x. More...
template<typename genIUType >
GLM_FUNC_DECL genIUType | bitfieldFillOne (genIUType Value, int FirstBit, int BitCount)
| Set to 1 a range of bits. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | bitfieldFillOne (vec< L, T, Q > const &Value, int FirstBit, int BitCount)
| Set to 1 a range of bits. More...
template<typename genIUType >
GLM_FUNC_DECL genIUType | bitfieldFillZero (genIUType Value, int FirstBit, int BitCount)
| Set to 0 a range of bits. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | bitfieldFillZero (vec< L, T, Q > const &Value, int FirstBit, int BitCount)
| Set to 0 a range of bits. More...
GLM_FUNC_DECL int32 | bitfieldInterleave (int16 x, int16 y)
| Interleaves the bits of x and y. More...
GLM_FUNC_DECL int64 | bitfieldInterleave (int16 x, int16 y, int16 z)
| Interleaves the bits of x, y and z. More...
GLM_FUNC_DECL int64 | bitfieldInterleave (int16 x, int16 y, int16 z, int16 w)
| Interleaves the bits of x, y, z and w. More...
GLM_FUNC_DECL int64 | bitfieldInterleave (int32 x, int32 y)
| Interleaves the bits of x and y. More...
GLM_FUNC_DECL int64 | bitfieldInterleave (int32 x, int32 y, int32 z)
| Interleaves the bits of x, y and z. More...
GLM_FUNC_DECL int16 | bitfieldInterleave (int8 x, int8 y)
| Interleaves the bits of x and y. More...
GLM_FUNC_DECL int32 | bitfieldInterleave (int8 x, int8 y, int8 z)
| Interleaves the bits of x, y and z. More...
GLM_FUNC_DECL int32 | bitfieldInterleave (int8 x, int8 y, int8 z, int8 w)
| Interleaves the bits of x, y, z and w. More...
GLM_FUNC_DECL uint32 | bitfieldInterleave (u16vec2 const &v)
| Interleaves the bits of x and y. More...
GLM_FUNC_DECL uint64 | bitfieldInterleave (u32vec2 const &v)
| Interleaves the bits of x and y. More...
GLM_FUNC_DECL uint16 | bitfieldInterleave (u8vec2 const &v)
| Interleaves the bits of x and y. More...
GLM_FUNC_DECL uint32 | bitfieldInterleave (uint16 x, uint16 y)
| Interleaves the bits of x and y. More...
GLM_FUNC_DECL uint64 | bitfieldInterleave (uint16 x, uint16 y, uint16 z)
| Interleaves the bits of x, y and z. More...
GLM_FUNC_DECL uint64 | bitfieldInterleave (uint16 x, uint16 y, uint16 z, uint16 w)
| Interleaves the bits of x, y, z and w. More...
GLM_FUNC_DECL uint64 | bitfieldInterleave (uint32 x, uint32 y)
| Interleaves the bits of x and y. More...
GLM_FUNC_DECL uint64 | bitfieldInterleave (uint32 x, uint32 y, uint32 z)
| Interleaves the bits of x, y and z. More...
GLM_FUNC_DECL uint16 | bitfieldInterleave (uint8 x, uint8 y)
| Interleaves the bits of x and y. More...
GLM_FUNC_DECL uint32 | bitfieldInterleave (uint8 x, uint8 y, uint8 z)
| Interleaves the bits of x, y and z. More...
GLM_FUNC_DECL uint32 | bitfieldInterleave (uint8 x, uint8 y, uint8 z, uint8 w)
| Interleaves the bits of x, y, z and w. More...
template<typename genIUType >
GLM_FUNC_DECL genIUType | bitfieldRotateLeft (genIUType In, int Shift)
| Rotate all bits to the left. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | bitfieldRotateLeft (vec< L, T, Q > const &In, int Shift)
| Rotate all bits to the left. More...
template<typename genIUType >
GLM_FUNC_DECL genIUType | bitfieldRotateRight (genIUType In, int Shift)
| Rotate all bits to the right. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | bitfieldRotateRight (vec< L, T, Q > const &In, int Shift)
| Rotate all bits to the right. More...
template<typename genIUType >
GLM_FUNC_DECL genIUType | mask (genIUType Bits)
| Build a mask of 'count' bits. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | mask (vec< L, T, Q > const &v)
| Build a mask of 'count' bits. More...

## Detailed Description

GLM_GTC_bitfield

See also
  Core features (dependence)
  GLM_GTC_bitfield (dependence)

Definition in file bitfield.hpp.